==> servicecatalog-0.20.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/PortfolioPrincipalAssociationResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolioprincipalassociation.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-13T10:23:12.482Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.PortfolioPrincipalAssociationResource")
public class PortfolioPrincipalAssociationResource extends software.amazon.awscdk.Resource {
    protected PortfolioPrincipalAssociationResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::PortfolioPrincipalAssociation``.
     * @param parent the ``cdk.Construct`` this ``PortfolioPrincipalAssociationResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``PortfolioPrincipalAssociationResource``
     */
    public PortfolioPrincipalAssociationResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getPortfolioPrincipalAssociationId() {
        return this.jsiiGet("portfolioPrincipalAssociationId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResourceProps.class);
    }
}

==> servicecatalog-0.21.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/PortfolioPrincipalAssociationResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @deprecated "cloudformation.PortfolioPrincipalAssociationResource" will be deprecated in a future release in favor of "CfnPortfolioPrincipalAssociation" (see https://github.com/awslabs/aws-cdk/issues/878)
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolioprincipalassociation.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:28:54.836Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.PortfolioPrincipalAssociationResource")
public class PortfolioPrincipalAssociationResource extends software.amazon.awscdk.Resource {
    protected PortfolioPrincipalAssociationResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::PortfolioPrincipalAssociation``.
     * @param parent the ``cdk.Construct`` this ``PortfolioPrincipalAssociationResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``PortfolioPrincipalAssociationResource``
     */
    public PortfolioPrincipalAssociationResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getPortfolioPrincipalAssociationId() {
        return this.jsiiGet("portfolioPrincipalAssociationId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioPrincipalAssociationResourceProps.class);
    }
}
